==> CartMadeSimple0.1.0.zip: CartMadeSimple/action.orderthankyou.php <==
<?php
# Module: Cart Made Simple - An Order Intake module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown <duketown@mantox.nl>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/teamsportscores
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

global $gCms;
$db =& $gCms->GetDb();

$thankyoupage = $this->GetPreference('contentthankyou', '');
if ( $thankyoupage != '' ) {
	// Retrieve the page containing the thank you material
	$query = 'SELECT content_id FROM '.cms_db_prefix().'content WHERE menu_text = ?';
	$dbresult = $db->Execute( $query, array( $thankyoupage ));
	$row = $dbresult->FetchRow();
	$return_id = $row['content_id'];
	// Return to the page as set up in the options
	$this->RedirectContent ( $return_id );
}
else {
	$this->smarty->assign('message', $this->Lang('title_welcomethankyou'));
}

#Display template
$this->smarty->assign('startform', $this->CreateFormStart($id, 'orderthankyou', $returnid));
$this->smarty->assign('endform', $this->CreateFormEnd());

echo $this->ProcessTemplate('fe_thankyou_info.tpl');
?>

==> CartMadeSimple0.1.1.zip: CartMadeSimple/action.orderthankyou.php <==
<?php
# Module: Cart Made Simple - An Order Intake module for CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown <duketown@mantox.nl>
#
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/cartms
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

global $gCms;
$db =& $gCms->GetDb();

$thankyoupage = $this->GetPreference('contentthankyou', '');
if ( $thankyoupage != '' ) {
	// Retrieve the page containing the thank you material
	$query = 'SELECT content_id FROM '.cms_db_prefix().'content WHERE menu_text = ?';
	$dbresult = $db->Execute( $query, array( $thankyoupage ));
	$row = $dbresult->FetchRow();
	$return_id = $row['content_id'];
	// Return to the page as set up in the options
	$this->RedirectContent ( $return_id );
}
else {
	$this->smarty->assign('message', $this->Lang('title_welcomethankyou'));
}

#Display template
$this->smarty->assign('startform', $this->CreateFormStart($id, 'orderthankyou', $returnid));
$this->smarty->assign('endform', $this->CreateFormEnd());

// Set default template. If past as parameter, show that one
$template = 'cart_fe_thankyou_info';
if (isset($params['template_thankyou_info']))
  {
    $template = 'cart_'.$params['template_thankyou_info'];
  }
echo $this->ProcessTemplateFromDatabase($template);
?>
